@@ -1,6 +1,8 @@
 from logging import Logger
 from requests import Session
+from typing import Dict
 from dapodik.config import BASE_URL
+from .dapodik_object import DapodikObject
 
 
 class BaseDapodik:
@@ -8,3 +10,4 @@ class BaseDapodik:
     domain: str = BASE_URL
     sekolah_id: str = None
     logger: Logger = None
+    id_map: Dict[str, DapodikObject] = {}
