@@ -1,11 +1,10 @@
 from dataclasses import dataclass
 from typing import Optional
 from dapodik.base import DapodikObject
-from dapodik.sekolah import Sekolah
-from dapodik.rest import (JenjangPendidikan, Pekerjaan, Penghasilan,
-                          KebutuhanKhusus)
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('peserta_didik_id')
 @dataclass(eq=False)
 class PesertaDidik(DapodikObject):
     nama: str
@@ -13,7 +12,7 @@ class PesertaDidik(DapodikObject):
     tempat_lahir: str
     tanggal_lahir: str
     nama_ibu_kandung: str
-    sekolah_id: Sekolah
+    sekolah_id: str
     pdb_id: str
     tahun_lahir_ayah: int
     tahun_lahir_ibu: int
@@ -38,7 +37,7 @@ class PesertaDidik(DapodikObject):
     no_kk: str = ""
     reg_akta_lahir: str = ""
     agama_id_str: str = ""
-    kebutuhan_khusus_id: KebutuhanKhusus = 0
+    kebutuhan_khusus_id: int = 0
     kebutuhan_khusus_id_str: str = ""
     jenis_tinggal_id: int = 1
     alat_transportasi_id: int = 1
@@ -62,30 +61,30 @@ class PesertaDidik(DapodikObject):
     status_data: int = 0
     nama_ayah: str = ""
     nik_ayah: str = ""
-    jenjang_pendidikan_ayah: JenjangPendidikan = 0
+    jenjang_pendidikan_ayah: int = 0
     jenjang_pendidikan_ayah_str: str = ""
-    pekerjaan_id_ayah: Pekerjaan = 0
+    pekerjaan_id_ayah: int = 0
     pekerjaan_id_ayah_str: str = ""
-    penghasilan_id_ayah: Penghasilan = 0
+    penghasilan_id_ayah: int = 0
     penghasilan_id_ayah_str: str = ""
-    kebutuhan_khusus_id_ayah: KebutuhanKhusus = 0
+    kebutuhan_khusus_id_ayah: int = 0
     kebutuhan_khusus_id_ayah_str: str = ""
     nik_ibu: str = ""
-    jenjang_pendidikan_ibu: JenjangPendidikan = 0
+    jenjang_pendidikan_ibu: int = 0
     jenjang_pendidikan_ibu_str: str = ""
-    pekerjaan_id_ibu: Pekerjaan = 1
+    pekerjaan_id_ibu: int = 1
     pekerjaan_id_ibu_str: str = ""
-    penghasilan_id_ibu: Penghasilan = 99
+    penghasilan_id_ibu: int = 99
     penghasilan_id_ibu_str: str = ""
-    kebutuhan_khusus_id_ibu: KebutuhanKhusus = 0
+    kebutuhan_khusus_id_ibu: int = 0
     kebutuhan_khusus_id_ibu_str: str = ""
     nama_wali: str = ""
     nik_wali: str = ""
-    jenjang_pendidikan_wali: JenjangPendidikan = 0
+    jenjang_pendidikan_wali: int = 0
     jenjang_pendidikan_wali_str: str = ""
-    pekerjaan_id_wali: Pekerjaan = 0
+    pekerjaan_id_wali: int = 0
     pekerjaan_id_wali_str: str = ""
-    penghasilan_id_wali: Penghasilan = 0
+    penghasilan_id_wali: int = 0
     penghasilan_id_wali_str: str = ""
     nomor_telepon_rumah: str = ""
     nomor_telepon_seluler: str = ""
@@ -93,7 +92,6 @@ class PesertaDidik(DapodikObject):
     kebutuhan_khusus_id_selector = []
     kebutuhan_khusus_id_selector_ayah = []
     kebutuhan_khusus_id_selector_ibu = []
-    _id: str = 'peserta_didik_id'
 
     @property
     def params(self):
