@@ -2,8 +2,11 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.rest import JenisKeluar
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('ptk_terdaftar_id')
 @dataclass(eq=False)
 class PtkTerdaftar(DapodikObject):
     ptk_terdaftar_id: str
@@ -36,4 +39,8 @@ class PtkTerdaftar(DapodikObject):
     ptk_id_str: str
     sekolah_id_str: str
     tahun_ajaran_id_str: str
-    _id: str = 'ptk_terdaftar_id'
+
+    @property
+    @JenisKeluar.getter
+    def jenis_keluar(self) -> Optional[JenisKeluar]:
+        return self.jenis_keluar_id
