@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('akses_internet_id')
 @dataclass(eq=False)
 class AksesInternet(DapodikObject):
     akses_internet_id: int
@@ -13,4 +15,3 @@ class AksesInternet(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'akses_internet_id'
