@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('alat_transportasi_id')
 @dataclass(eq=False)
 class AlatTransportasi(DapodikObject):
     alat_transportasi_id: str
@@ -12,4 +14,3 @@ class AlatTransportasi(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'alat_transportasi_id'
