@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('jadwal_id')
 @dataclass(eq=False)
 class JadwalPaud(DapodikObject):
     jadwal_id: str
@@ -16,4 +18,3 @@ class JadwalPaud(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'jadwal_id'
