@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('id_jenis_lk')
 @dataclass(eq=False)
 class JenisLk(DapodikObject):
     id_jenis_lk: str
@@ -13,4 +15,3 @@ class JenisLk(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'id_jenis_lk'
