@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('id_hapus_buku')
 @dataclass(eq=False)
 class JenisSarana(DapodikObject):
     id_hapus_buku: str
@@ -14,4 +16,3 @@ class JenisSarana(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'id_hapus_buku'
