@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('klasifikasi_lembaga_id')
 @dataclass(eq=False)
 class KlasifikasiLembaga(DapodikObject):
     klasifikasi_lembaga_id: str
@@ -12,4 +14,3 @@ class KlasifikasiLembaga(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'klasifikasi_lembaga_id'
