@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('sumber_air_id')
 @dataclass(eq=False)
 class SumberAir(DapodikObject):
     sumber_air_id: str
@@ -14,4 +16,3 @@ class SumberAir(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'sumber_air_id'
