@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from dapodik.base import DapodikObject
 from typing import Optional
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('sumber_listrik_id')
 @dataclass(eq=False)
 class SumberListrik(DapodikObject):
     sumber_listrik_id: str
@@ -12,4 +14,3 @@ class SumberListrik(DapodikObject):
     last_update: datetime
     expired_date: Optional[datetime]
     last_sync: datetime
-    _id: str = 'sumber_listrik_id'
