@@ -1,8 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('sync_log_id')
 @dataclass(eq=False)
 class SyncLog(DapodikObject):
     id_instalasi: str
@@ -14,4 +16,3 @@ class SyncLog(DapodikObject):
     alamat_ip: str
     pengguna_id: str
     sync_log_id: str
-    _id: str = 'sync_log_id'
