@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('alat_dari_blockgrant_id')
 @dataclass(eq=False)
 class AlatDariBlockgrant(DapodikObject):
     blockgrant_id: str
@@ -16,4 +18,3 @@ class AlatDariBlockgrant(DapodikObject):
     blockgrant_id_str: str
     id_alat_str: str = ''
     alat_dari_blockgrant_id: Optional[str] = 'Admin.model.AlatDariBlockgrant-1'
-    _id: str = 'alat_dari_blockgrant_id'
