@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('id_bangunan')
 @dataclass(eq=False)
 class Bangunan(DapodikObject):
     id_bangunan: str
@@ -53,4 +55,3 @@ class Bangunan(DapodikObject):
     id_tanah_str: str
     sekolah_id_str: str
     vld_count: int
-    _id: str = 'id_bangunan'
