@@ -1,9 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('bangunan_dari_blockgrant_id')
 @dataclass(eq=False)
 class BangunanDariBlockgrant(DapodikObject):
     blockgrant_id: str
@@ -16,4 +17,3 @@ class BangunanDariBlockgrant(DapodikObject):
     blockgrant_id_str: str
     id_bangunan_str: str
     bangunan_dari_blockgrant_id: str
-    _id: str = 'bangunan_dari_blockgrant_id'
