@@ -1,9 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('bangunan_longitudinal_id')
 @dataclass(eq=False)
 class BangunanLongitudinal(DapodikObject):
     id_bangunan: str
@@ -31,4 +32,3 @@ class BangunanLongitudinal(DapodikObject):
     id_bangunan_str: str
     semester_id_str: str
     bangunan_longitudinal_id: str
-    _id: str = 'bangunan_longitudinal_id'
