@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('ruang_longitudinal_id')
 @dataclass(eq=False)
 class RuangLongitudinal(DapodikObject):
     id_ruang: str
@@ -50,4 +52,3 @@ class RuangLongitudinal(DapodikObject):
     id_ruang_str: str
     semester_id_str: str
     ruang_longitudinal_id: str
-    _id: str = 'ruang_longitudinal_id'
