@@ -1,8 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('id_panitia')
 @dataclass(eq=False)
 class Kepanitiaan(DapodikObject):
     id_panitia: str
