@@ -2,8 +2,10 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('id_panitia')
 @dataclass(eq=False)
 class ProgramInklusi(DapodikObject):
     id_pi: str
