@@ -1,8 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
 from dapodik.base import DapodikObject
+from dapodik.utils.decorator import set_meta
 
 
+@set_meta('kategori_tk_id')
 @dataclass(eq=False)
 class SekolahPaud(DapodikObject):
     sekolah_id: str
@@ -34,4 +36,4 @@ class SekolahPaud(DapodikObject):
     last_update: datetime
     soft_delete: str
     last_sync: datetime
-    updater_id: str
\ No newline at end of file
+    updater_id: str
